import click

import polars as pl
import pandas as pd

import time 

@click.command("simple")
@click.argument("filename")

def simple(filename):

    print ("--------------------------------  Polars processing ---------------------------------------")
    
    start = time.time()
    df_polars = pl.read_ipc(filename,memory_map=True)
    print(df_polars)
    end = time.time()

    print(f"Elapsed Time : {end - start}")

    print ("--------------------------------  Pandas processing ---------------------------------------")
    
    start = time.time()
    df_pandas = pd.read_feather(filename)
    print(df_pandas)
    end = time.time()

    print(f"Elapsed Time : {end - start}")

    print ("--------------------------------  All the fields    ---------------------------------------")
    print(df_pandas.head(1).T)


    print ("--------------------------------  All the fireflies ---------------------------------------")
    df_fireflies = pd.read_feather("../firefly.arrow")
    print(df_fireflies.head(1).T)

    print ("""
-------------------------------------------Notes ------------------------------------------
  1. The fireflies have not been reduced to just this experiment. So it is a bit of work to only extract
     the subset that matter

  2. Each of the denv-ht1 and star-ht directores has the following structure:

.
├── denv-ht1
│   ├── 11
│   │   └── split_files
│   │       └── run_1_2023-11-14_12:00:00+00:00_to_2023-11-14_16:00:00+00:00
│   └── 12
│       └── split_files
│           └── run_1_2023-11-14_12:00:00+00:00_to_2023-11-14_16:00:00+00:00
└── star-ht1
    ├── 11
    │   └── split_files
    │       └── run_1_2023-11-14_12:00:00+00:00_to_2023-11-14_16:00:00+00:00
    └── 12
        └── split_files
            └── run_1_2023-11-14_12:00:00+00:00_to_2023-11-14_16:00:00+00:00

   the 11, and 12 represent the two directions for a single flow.  
      client to server and server to client.

   3.  The full data files cannot be relied upon to contain all the packets for a time range.  Instead the
       summary files should be read and examined to find out which .arrow_ipc files need to be opened

""")

if __name__ == "__main__":
    simple()

